"""此模块用于打印嵌套列表"""
def print_lol(the_list,level):
	for each_item in the_list:
		if isinstance(each_item, list):
			print_lol(each_item,level+1)
		else:
            for item in range(level):
                print("\t",end='')
			print(each_item)


from distutils.core import setup

setup(
	name		= '20191004',
	version		= '1.1.0',
	py_modules	= ['netster'],
	author		= 'hfpython',
	author_email= 'hfpython@headfirstlabs.com',
	url			= 'http://www.headfirstlabs.com',
	description = 'A simple printer of nested lists',
	)
	